@@ -8,8 +8,8 @@
 #include <KDBusService>
 #include <KLocalizedString>
 
-#include "global.h"
 #include "channellogger.h"
+#include "global.h"
 
 int main(int argc, char *argv[])
 {
@@ -20,6 +20,10 @@ int main(int argc, char *argv[])
     QCoreApplication::setOrganizationDomain(SL("kde.org"));
     QCoreApplication::setApplicationName(SL("Spacebar"));
 
+    KLocalizedString::setApplicationDomain("spacebar");
+
+    app.setQuitLockEnabled(false); // prevent a finishing KJob from closing the daemon
+
     parser.addVersionOption();
     parser.addHelpOption();
     parser.setApplicationDescription(i18n("Spacebar background service"));
@@ -30,9 +34,7 @@ int main(int argc, char *argv[])
     KDBusService service(KDBusService::Unique);
 
     // Create observer
-    auto modemPath = parser.isSet(modemOpt) && !parser.value(modemOpt).isEmpty()
-            ? parser.value(modemOpt)
-            : std::optional<QString>();
+    auto modemPath = parser.isSet(modemOpt) && !parser.value(modemOpt).isEmpty() ? parser.value(modemOpt) : std::optional<QString>();
 
     ChannelLogger logger(modemPath);
 
