@@ -6,10 +6,12 @@
 
 #include <functional>
 
-#include <QString>
-#include <QSharedDataPointer>
-#include <QDebug>
 #include <QDBusArgument>
+#include <QDebug>
+#include <QSharedDataPointer>
+#include <QString>
+
+#include <global.h>
 
 struct PhoneNumberPrivate;
 
@@ -42,12 +44,14 @@ private:
     static std::string countryCode;
 };
 
-inline QDebug &operator<<(QDebug &debug, const PhoneNumber &phoneNumber) {
+inline QDebug &operator<<(QDebug &debug, const PhoneNumber &phoneNumber)
+{
     return debug << phoneNumber.toInternational();
 }
 
-inline uint qHash(const PhoneNumber &phoneNum) {
-    return qHash(phoneNum.toInternational());
+inline uint qHash(const PhoneNumber &phoneNum)
+{
+    return hash(phoneNum.toInternational());
 }
 
 Q_DECLARE_METATYPE(PhoneNumber)
