@@ -3,40 +3,40 @@
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include <KAboutData>
+#include <KDBusService>
 #include <KLocalizedContext>
 #include <KLocalizedString>
+#include <KWindowSystem>
 
 #include <QApplication>
+#include <QCommandLineParser>
 #include <QQmlApplicationEngine>
-#include <QUrl>
-#include <QtQml>
 #include <QQuickStyle>
 #include <QQuickWindow>
-#include <QCommandLineParser>
+#include <QUrl>
+#include <QtQml>
 
 // Models
 #include "chatlistmodel.h"
 #include "messagemodel.h"
 
-#include <contactphonenumbermapper.h>
-#include "version.h"
-#include "global.h"
-#include "utils.h"
 #include "about.h"
 #include "avatarimageprovider.h"
 #include "channelhandler.h"
+#include "global.h"
 #include "settingsmanager.h"
+#include "utils.h"
+#include "version.h"
+#include <contactphonenumbermapper.h>
 
 #include <coroutine>
 #include <phonenumberlist.h>
 
 constexpr auto APPLICATION_ID = "org.kde.spacebar";
 
-
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QCommandLineParser parser;
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
 
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE") && QQuickStyle::name().isEmpty()) {
@@ -49,6 +49,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QCoreApplication::setApplicationVersion(QStringLiteral(SPACEBAR_VERSION_STRING));
     QGuiApplication::setApplicationDisplayName(SL("Spacebar"));
 
+    KLocalizedString::setApplicationDomain("spacebar");
+
     KAboutData about(SL("spacebar"),
                      SL("Spacebar"),
                      QStringLiteral(SPACEBAR_VERSION_STRING),
@@ -70,7 +72,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     parser.addPositionalArgument(QStringLiteral("number"), i18n("Open a chat with the given phone number"));
     parser.process(app);
 
-    KLocalizedString::setApplicationDomain("spacebar");
+    KDBusService service(KDBusService::Unique);
 
     QQmlApplicationEngine engine;
 
@@ -98,17 +100,35 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         return -1;
     }
 
-    if (!parser.positionalArguments().isEmpty()) {
-        QString numberArg = parser.positionalArguments().constFirst();
-        if (numberArg.startsWith(QStringLiteral("sms:"))) {
-            numberArg = numberArg.mid(4);
+    auto handleArgs = [&parser, &chatListModel] {
+        if (!parser.positionalArguments().isEmpty()) {
+            QString numberArg = parser.positionalArguments().constFirst();
+            if (numberArg.startsWith(QStringLiteral("sms:"))) {
+                numberArg = numberArg.mid(4);
+            }
+            if (Utils::instance()->isPhoneNumber(numberArg)) {
+                chatListModel.startChat(PhoneNumberList(numberArg));
+            } else {
+                qWarning() << "invalid phone number on command line, ignoring";
+            }
         }
-        if (Utils::instance()->isPhoneNumber(numberArg)) {
-            chatListModel.startChat(PhoneNumberList(numberArg));
-        } else {
-            qWarning() << "invalid phone number on command line, ignoring";
+    };
+
+    QObject::connect(&service, &KDBusService::activateRequested, &service, [&parser, &handleArgs, &engine](const QStringList &args) {
+        parser.parse(args);
+        handleArgs();
+
+        // Move window to the front
+        auto *window = qobject_cast<QWindow *>(engine.rootObjects().constFirst());
+        if (window) {
+            window->hide(); // Hack - remove once works correctly without
+            KWindowSystem::updateStartupId(window);
+            KWindowSystem::activateWindow(window);
+            window->show(); // Hack - remove once works correctly without
         }
-    }
+    });
+
+    handleArgs();
 
     return app.exec();
 }
